==> openshift-model-tuned-6.12.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileStatusFluent.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ProfileStatusFluent<A extends ProfileStatusFluent<A>> extends BaseFluent<A>{
  public ProfileStatusFluent() {
  }
  
  public ProfileStatusFluent(ProfileStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ProfileStatusConditionBuilder> conditions = new ArrayList<ProfileStatusConditionBuilder>();
  private String tunedProfile;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ProfileStatus instance) {
    instance = (instance != null ? instance : new ProfileStatus());
    if (instance != null) {
          this.withConditions(instance.getConditions());
          this.withTunedProfile(instance.getTunedProfile());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToConditions(int index,ProfileStatusCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  
  public A setToConditions(int index,ProfileStatusCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  
  public A addToConditions(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A addAllToConditions(Collection<ProfileStatusCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A removeFromConditions(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusCondition... items) {
    if (this.conditions == null) return (A)this;
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConditions(Collection<ProfileStatusCondition> items) {
    if (this.conditions == null) return (A)this;
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConditions(Predicate<ProfileStatusConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<ProfileStatusConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      ProfileStatusConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ProfileStatusCondition> buildConditions() {
    return this.conditions != null ? build(conditions) : null;
  }
  
  public ProfileStatusCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  
  public ProfileStatusCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  
  public ProfileStatusCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  
  public ProfileStatusCondition buildMatchingCondition(Predicate<ProfileStatusConditionBuilder> predicate) {
      for (ProfileStatusConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCondition(Predicate<ProfileStatusConditionBuilder> predicate) {
      for (ProfileStatusConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withConditions(List<ProfileStatusCondition> conditions) {
    if (this.conditions != null) {
      this._visitables.get("conditions").clear();
    }
    if (conditions != null) {
        this.conditions = new ArrayList();
        for (ProfileStatusCondition item : conditions) {
          this.addToConditions(item);
        }
    } else {
      this.conditions = null;
    }
    return (A) this;
  }
  
  public A withConditions(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusCondition... conditions) {
    if (this.conditions != null) {
        this.conditions.clear();
        _visitables.remove("conditions");
    }
    if (conditions != null) {
      for (ProfileStatusCondition item : conditions) {
        this.addToConditions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasConditions() {
    return this.conditions != null && !this.conditions.isEmpty();
  }
  
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type) {
    return (A)addToConditions(new ProfileStatusCondition(lastTransitionTime, message, reason, status, type));
  }
  
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  
  public ConditionsNested<A> addNewConditionLike(ProfileStatusCondition item) {
    return new ConditionsNested(-1, item);
  }
  
  public ConditionsNested<A> setNewConditionLike(int index,ProfileStatusCondition item) {
    return new ConditionsNested(index, item);
  }
  
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editMatchingCondition(Predicate<ProfileStatusConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public String getTunedProfile() {
    return this.tunedProfile;
  }
  
  public A withTunedProfile(String tunedProfile) {
    this.tunedProfile = tunedProfile;
    return (A) this;
  }
  
  public boolean hasTunedProfile() {
    return this.tunedProfile != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProfileStatusFluent that = (ProfileStatusFluent) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;
    if (!java.util.Objects.equals(tunedProfile, that.tunedProfile)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditions,  tunedProfile,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (tunedProfile != null) { sb.append("tunedProfile:"); sb.append(tunedProfile + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends ProfileStatusConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,ProfileStatusCondition item) {
      this.index = index;
      this.builder = new ProfileStatusConditionBuilder(this, item);
    }
    ProfileStatusConditionBuilder builder;
    int index;
    
    public N and() {
      return (N) ProfileStatusFluent.this.setToConditions(index,builder.build());
    }
    
    public N endCondition() {
      return and();
    }
    
  
  }

}

==> openshift-model-tuned-7.2.0-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileStatusFluent.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ProfileStatusFluent<A extends ProfileStatusFluent<A>> extends BaseFluent<A>{
  public ProfileStatusFluent() {
  }
  
  public ProfileStatusFluent(ProfileStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ProfileStatusConditionBuilder> conditions = new ArrayList<ProfileStatusConditionBuilder>();
  private String tunedProfile;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ProfileStatus instance) {
    instance = (instance != null ? instance : new ProfileStatus());
    if (instance != null) {
          this.withConditions(instance.getConditions());
          this.withTunedProfile(instance.getTunedProfile());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToConditions(int index,ProfileStatusCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) {
        _visitables.get("conditions").add(builder);
        conditions.add(builder);
    } else {
        _visitables.get("conditions").add(builder);
        conditions.add(index, builder);
    }
    return (A)this;
  }
  
  public A setToConditions(int index,ProfileStatusCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) {
        _visitables.get("conditions").add(builder);
        conditions.add(builder);
    } else {
        _visitables.get("conditions").add(builder);
        conditions.set(index, builder);
    }
    return (A)this;
  }
  
  public A addToConditions(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A addAllToConditions(Collection<ProfileStatusCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ProfileStatusConditionBuilder>();}
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A removeFromConditions(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusCondition... items) {
    if (this.conditions == null) return (A)this;
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConditions(Collection<ProfileStatusCondition> items) {
    if (this.conditions == null) return (A)this;
    for (ProfileStatusCondition item : items) {ProfileStatusConditionBuilder builder = new ProfileStatusConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConditions(Predicate<ProfileStatusConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<ProfileStatusConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      ProfileStatusConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ProfileStatusCondition> buildConditions() {
    return this.conditions != null ? build(conditions) : null;
  }
  
  public ProfileStatusCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  
  public ProfileStatusCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  
  public ProfileStatusCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  
  public ProfileStatusCondition buildMatchingCondition(Predicate<ProfileStatusConditionBuilder> predicate) {
      for (ProfileStatusConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCondition(Predicate<ProfileStatusConditionBuilder> predicate) {
      for (ProfileStatusConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withConditions(List<ProfileStatusCondition> conditions) {
    if (this.conditions != null) {
      this._visitables.get("conditions").clear();
    }
    if (conditions != null) {
        this.conditions = new ArrayList();
        for (ProfileStatusCondition item : conditions) {
          this.addToConditions(item);
        }
    } else {
      this.conditions = null;
    }
    return (A) this;
  }
  
  public A withConditions(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusCondition... conditions) {
    if (this.conditions != null) {
        this.conditions.clear();
        _visitables.remove("conditions");
    }
    if (conditions != null) {
      for (ProfileStatusCondition item : conditions) {
        this.addToConditions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasConditions() {
    return this.conditions != null && !this.conditions.isEmpty();
  }
  
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type) {
    return (A)addToConditions(new ProfileStatusCondition(lastTransitionTime, message, reason, status, type));
  }
  
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  
  public ConditionsNested<A> addNewConditionLike(ProfileStatusCondition item) {
    return new ConditionsNested(-1, item);
  }
  
  public ConditionsNested<A> setNewConditionLike(int index,ProfileStatusCondition item) {
    return new ConditionsNested(index, item);
  }
  
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editMatchingCondition(Predicate<ProfileStatusConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public String getTunedProfile() {
    return this.tunedProfile;
  }
  
  public A withTunedProfile(String tunedProfile) {
    this.tunedProfile = tunedProfile;
    return (A) this;
  }
  
  public boolean hasTunedProfile() {
    return this.tunedProfile != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProfileStatusFluent that = (ProfileStatusFluent) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;
    if (!java.util.Objects.equals(tunedProfile, that.tunedProfile)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditions,  tunedProfile,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (tunedProfile != null) { sb.append("tunedProfile:"); sb.append(tunedProfile + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends ProfileStatusConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,ProfileStatusCondition item) {
      this.index = index;
      this.builder = new ProfileStatusConditionBuilder(this, item);
    }
    ProfileStatusConditionBuilder builder;
    int index;
    
    public N and() {
      return (N) ProfileStatusFluent.this.setToConditions(index,builder.build());
    }
    
    public N endCondition() {
      return and();
    }
    
  
  }

}
